<?php
/**
 * Set scribbler layout according to options
 *
 * @package Scribbler
 */

defined( 'WPINC' ) || exit;

/**
 * Layout manager.
 */
class Scribbler_Layout extends Scribbler_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'scribbler_before_wrapper', 'add_header' );
		$this->add_action( 'scribbler_single_post_header_thumb', 'single_post_header_thumb' );
		$this->add_action( 'scribbler_blog_page_title_section', 'blog_page_title_section' );
		$this->add_action( 'scribbler_pages_title_section', 'pages_title_section' );
		$this->add_action( 'scribbler_before_footer', 'full_related_posts' );
	}

	/**
	 * Add header
	 */
	public function add_header() {
		$hash   = array(
			'header-default' => 'default',
			'header-layout2' => 'layout2',
		);
		$layout = scribbler_get_settings( 'header_styles' );
		get_template_part( 'template-parts/header/header', isset( $hash[ $layout ] ) ? $hash[ $layout ] : $layout );
	}

	/**
	 * Single post header thumbnail
	 */
	public function single_post_header_thumb() {

		$header_animation = scribbler_get_post_header_effect();

		if ( has_post_thumbnail() ) {
			if ( ! $header_animation && scribbler_get_settings( 'show_single_featured' ) ) {
				$attr = [
					'class'   => 'single-featured-image',
					'title'   => esc_attr( get_the_title() ),
					'alt'     => esc_attr( get_the_title() ),
					'loading' => 'lazy',
				];
				the_post_thumbnail( 'scribbler-featured', $attr );
			}
		}
	}

	/**
	 * Blog Page Title
	 */
	function blog_page_title_section() {
		if ( scribbler_get_settings( 'show_blog_title' ) && ! is_paged() ) :
			?>
			<div class="pages-title-section">
				<div class="container">
					<?php
					$show_icon     = scribbler_get_settings( 'show_blog_icon' );
					$icon          = scribbler_get_settings( 'blog_icon' );
					$blog_title    = scribbler_get_settings( 'blog_title' );
					$blog_subtitle = scribbler_get_settings( 'blog_subtitle' );
					$show_arrow    = scribbler_get_settings( 'show_arrow_icon' );
					if ( ! empty( $show_icon ) && ! empty( $icon ) ) {
						echo '<div class="blog-icon"><i class="fa fa-' . $icon . '"></i></div>';
					}
					if ( ! empty( $blog_title ) ) {
						echo '<div class="blog-heading">' . $blog_title . '</div>';
					}
					if ( ! empty( $blog_subtitle ) ) {
						echo '<div class="blog-subheading">' . $blog_subtitle . '</div>';
					}
					if ( ! empty( $show_arrow ) ) {
						echo '<div class="blog-svg"><svg xmlns="http://www.w3.org/2000/svg"	xmlns:xlink="http://www.w3.org/1999/xlink"	width="29px" height="17px">
						<path fill-rule="evenodd"  stroke="rgb(239, 91, 97)" stroke-width="2px" stroke-linecap="round" stroke-linejoin="round" fill="none"
						 d="M2.000,2.000 L14.000,14.000 L26.000,2.000 "/></svg></div>';
					}
					?>
				</div>
			</div>
			<?php
		endif;
	}

	/**
	 * Pages Title Section
	 */
	function pages_title_section() {
		$header_animation = scribbler_get_post_header_effect();
		if ( is_page() && has_post_thumbnail() && ( 'parallax' === $header_animation || 'zoomout' === $header_animation ) ) {
			scribbler_single_featured_image_effect();
			return;
		}
		echo '<div class="pages-title-section">';
		echo '<div class="container clearfix">';
		$onpage = true;
		switch ( $onpage ) {
			case is_archive():
				the_archive_title( '<div class="blog-heading">', '</div>' );
				$onpage = false;
				break;

			case is_search():
				?>
				<div class="blog-heading"><?php echo esc_html__( 'Search', 'scribbler' ); ?></div>
				<?php
				$onpage = false;
				break;

			case is_page():
				?>
				<h1 class="blog-heading"><?php the_title(); ?></h1>
				<?php
				$onpage = false;
				break;

			case is_404():
				?>
				<div class="blog-heading"><?php echo esc_html_e( '404 Not Found', 'scribbler' ); ?></div>
				<?php
				$onpage = false;
				break;

			case scribbler_is_woocommerce_active():
				if ( function_exists( 'is_woocommerce' ) && is_woocommerce() && is_product() ) {
					?>
					<h1 class="blog-heading"><?php woocommerce_page_title(); ?></h1>
					<?php
				}
				if ( is_product() || is_cart() || is_checkout() || is_account_page() ) {
					?>
					<h1 class="blog-heading"><?php the_title(); ?></h1>
					<?php
				}
				$onpage = false;
				break;

			default:
				?>
				<h1 class="blog-heading"><?php the_title(); ?></h1>
				<?php
				$onpage = false;
				break;
		}
		echo '</div>';
		echo '</div>';
	}

	/**
	 * Single post related posts
	 */
	public function full_related_posts( $position = 'full' ) {

		if ( 'full' === scribbler_get_settings( 'related_posts_position' ) ) {
			scribbler_related_posts();
		}

	}

}

// Init.
new Scribbler_Layout;
