<?php
/**
 * Sidebars
 *
 * @package Scribbler
 */

defined( 'WPINC' ) || exit;

/**
 * Single sections
 */
class Scribbler_Single_Sections extends Scribbler_Base {

	public function render() {
	?>
	<article class="<?php scribbler_article_class(); ?>">
		<?php
		if ( 'mts_nosidebar' !== mts_custom_sidebar() ) {
			$sidebar = scribbler_custom_sidebar_layout();
		} else {
			$sidebar = 'nosidebar';
		}
		?>
		<div id="content_box" class="<?php echo $sidebar; ?>">
			<?php
			// Elementor 'single' location.
			if ( ! function_exists( 'elementor_theme_do_location' ) || ! elementor_theme_do_location( 'single' ) ) {
				if ( have_posts() ) :
					while ( have_posts() ) :
						the_post();
						if ( scribbler_get_settings( 'mts_breadcrumb' ) ) {
							scribbler_breadcrumbs();
						}
						?>
					<div id="post-<?php the_ID(); ?>" <?php post_class( 'g post' ); ?>>
						<?php
						// Single post parts ordering.
						if ( ( null !== scribbler_get_settings( 'mts_single_post_layout' ) ) && is_array( scribbler_get_settings( 'mts_single_post_layout' ) ) && array_key_exists( 'enabled', scribbler_get_settings( 'mts_single_post_layout' ) ) ) {
							$single_post_parts = scribbler_get_settings( 'mts_single_post_layout' )['enabled'];
						} else {
							$single_post_parts = array(
								'content'   => 'content',
								'tags'      => 'tags',
								'author'    => 'author',
								'related'   => 'related',
								'subscribe' => 'subscribe',
							);
						}

						foreach ( $single_post_parts as $part => $label ) {
							switch ( $part ) {
								// Content area.
								case 'content':
									scribbler()->single_sections->single_post();
									break;

								// Content area.
								case 'tags':
									scribbler_post_tags( '<div class="tags">', '' );
									break;

								// Author box.
								case 'author':
									scribbler()->single_sections->single_author_section();
									break;

								// Related Posts.
								case 'related':
									if ( 'default' === scribbler_get_settings( 'related_posts_position' ) ) {
										scribbler_related_posts();
									}
									break;

								// Subscribe box.
								case 'subscribe':
									scribbler()->single_sections->single_subscribe_box();
									break;
							}
						}
						?>
					</div><!--.g post-->
						<?php
						// Comment area.
						comments_template( '', true );

				endwhile;
					wp_reset_query();
			endif; /* end loop */
			}
			?>
		</div>
	</article>
		<?php
	}

	public function single_post() {
		?>
		<div class="single_post">
			<?php
			scribbler_action( 'single_post_header_thumb' );
			$this->single_post_header();
			?>
			<div class="post-single-content box mark-links entry-content">
				<?php
				$this->single_post_ads( 'above' );

				$this->single_post_social_icons( 'above' );

				$this->single_post_content();

				$this->single_post_pagination();

				$this->single_post_ads( 'below' );

				$this->single_post_social_icons( 'below' );
				?>
			</div><!--.post-single-content-->
		</div><!--.single_post-->
		<?php
	}

	/**
	 * Single post header
	 */
	public function single_post_header() {
		?>
		<header class="single-full-header clearfix">
			<?php get_single_metainfo( 'single' ); ?>
			<h1 class="title single-title entry-title"><?php the_title(); ?></h1>
		</header><!--.single-full-header-->
		<?php
	}

	/**
	 * Single Author Posts
	 */
	public function single_post_content() {

		echo '<div class="thecontent">';
			the_content();
		echo '</div>';
	}

	/**
	 * Single post pagination
	 */
	public function single_post_pagination() {
		// Single Post Pagination.
		$args = array(
			'before'           => '<div class="pagination">',
			'after'            => '</div>',
			'link_before'      => '<span class="current"><span class="currenttext">',
			'link_after'       => '</span></span>',
			'next_or_number'   => 'next_and_number',
			'nextpagelink'     => '<i class="fa fa-angle-right"></i>',
			'previouspagelink' => '<i class="fa fa-angle-left"></i>',
			'pagelink'         => '%',
			'echo'             => 1,
		);
		wp_link_pages( $args );
	}

	public function single_author_section() {
	?>
		<div class="postauthor">

			<?php
			// Author box title.
			$author_title = scribbler_get_settings( 'author_box_title' );
			if ( $author_title ) {
				echo '<h4>' . $author_title . '</h4>';
			}
			// Author gravatar.
			if ( scribbler_get_settings( 'author_box_image' ) && function_exists( 'get_avatar' ) ) {
				echo get_avatar( get_the_author_meta( 'email' ), '125' ); // Gravatar size.
			}
			?>
			<div class="postauthor-wrapper">
				<h5 class="vcard author">
					<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" class="fn">
						<?php the_author_meta( 'display_name' ); ?>
					</a>
				</h5>
				<p><?php the_author_meta( 'description' ); ?></p>
			</div>
		</div>
	<?php
	}

	public function single_subscribe_box() {
		if ( is_active_sidebar( 'single-subscribe' ) ) {
		?>
			<div class="single-subscribe clear">
				<?php dynamic_sidebar( 'single-subscribe' ); ?>
			</div>
		<?php
		}
	}

	public function single_post_ads( $location ) {
		// Above Content Ad Code.
		if ( ! empty( scribbler_get_settings( 'mts_posttop_adcode' ) ) && 'above' == $location ) {
			$toptime = ! empty( scribbler_get_settings( 'mts_posttop_adcode_time' ) ) ? scribbler_get_settings( 'mts_posttop_adcode_time' ) : '0';
			if ( strcmp( date( 'Y-m-d', strtotime( -$toptime . ' day' ) ), get_the_time( 'Y-m-d' ) ) >= 0 ) {
				?>
				<div class="topad">
					<?php echo do_shortcode( scribbler_get_settings( 'mts_posttop_adcode' ) ); ?>
				</div>
				<?php
			}
		}
		// Below Content Ad Code.
		if ( ! empty( scribbler_get_settings( 'mts_postend_adcode' ) ) && 'below' == $location ) {
			$endtime = ! empty( scribbler_get_settings( 'mts_postend_adcode_time' ) ) ? scribbler_get_settings( 'mts_postend_adcode_time' ) : '0';
			if ( strcmp( date( 'Y-m-d', strtotime( -$endtime . ' day' ) ), get_the_time( 'Y-m-d' ) ) >= 0 ) {
				?>
				<div class="bottomad">
					<?php echo do_shortcode( scribbler_get_settings( 'mts_postend_adcode' ) ); ?>
				</div>
				<?php
			}
		}
	}

	public function single_post_social_icons( $location ) {

		$position = scribbler_get_settings( 'mts_social_button_position' );

		// Social Share icons above content.
		if ( $position && ( 'top' === $position || 'both' === $position ) && 'above' == $location ) {
			scribbler_social_buttons( 'top' );
		}
		// Social Share icons below content.
		if ( $position && ( 'bottom' === $position || 'both' === $position ) && 'below' == $location ) {
			scribbler_social_buttons( 'bottom' );
		}
		// Social Share icons floating.
		if ( $position && 'floating' === $position ) {
			scribbler_social_buttons();
		}
	}

}
