<?php
/**
 * HomePage Pagination
 *
 * @package Scribbler
 */

$menus['blog']['child']['blog-pagination'] = array(
	'title' => esc_html__( 'Pagination', 'scribbler' ),
	'desc'  => esc_html__( 'From here, you can control the elements of pagination.', 'scribbler' ),
);

// Dependency check - Default and Numbered pagination.
$default_pagination_dependency = array(
	'relation' => 'and',
	array(
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '!=',
	),
	array(
		'field'      => 'mts_pagenavigation_type',
		'value'      => '3',
		'comparison' => '!=',
	),
);

// Dependency check the load more button.
$loadmore_button_dependency = array(
	'relation' => 'and',
	array(
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '==',
	),
);

$sections['blog-pagination'] = array(

	array(
		'id'       => 'mts_pagenavigation_type',
		'type'     => 'radio',
		'title'    => esc_html__( 'Pagination Type', 'scribbler' ),
		'sub_desc' => esc_html__( 'Select pagination type.', 'scribbler' ),
		'options'  => array(
			'0' => esc_html__( 'Default (Next / Previous)', 'scribbler' ),
			'1' => esc_html__( 'Numbered (1 2 3 4...)', 'scribbler' ),
			'2' => esc_html__( 'AJAX (Load More Button)', 'scribbler' ),
			'3' => esc_html__( 'AJAX (Auto Infinite Scroll)', 'scribbler' ),
		),
		'std'      => '1',
	),

	array(
		'id'         => 'pagenavigation_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Pagination Alignment', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Choose pagination alignment from here.', 'scribbler' ),
		'options'    => array(
			'left'   => esc_html__( 'Left', 'scribbler' ),
			'center' => esc_html__( 'Center', 'scribbler' ),
			'right'  => esc_html__( 'Right', 'scribbler' ),
		),
		'std'        => 'center',
		'dependency' => $default_pagination_dependency,
	),

	array(
		'id'         => 'load_more_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Load More Alignment', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Choose the load more alignment from here.', 'scribbler' ),
		'options'    => array(
			'left'   => esc_html__( 'Left', 'scribbler' ),
			'center' => esc_html__( 'Center', 'scribbler' ),
			'right'  => esc_html__( 'Right', 'scribbler' ),
			'full'   => esc_html__( 'Full Width', 'scribbler' ),
		),
		'std'        => 'center',
		'dependency' => $loadmore_button_dependency,
	),

	array(
		'id'         => 'mts_pagenavigation_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination background color', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Select pagination background color.', 'scribbler' ),
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More background color', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Select background color for load more button.', 'scribbler' ),
		'std'        => '#f2ebed',
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'         => 'mts_pagenavigation_hover_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination background hover color', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Select pagination background hover color.', 'scribbler' ),
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_hover_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More background hover color', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Select background hover color for load more button.', 'scribbler' ),
		'std'        => '#f2ebed',
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'         => 'mts_pagenavigation_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination color', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Select pagination color.', 'scribbler' ),
		'std'        => '#3f4351',
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More color', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Select color for load more button.', 'scribbler' ),
		'std'        => '#3f4351',
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'         => 'mts_pagenavigation_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination hover color', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Select pagination hover color.', 'scribbler' ),
		'std'        => scribbler_get_settings( 'primary_color_scheme' ),
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More hover color', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Select hover color for load more button.', 'scribbler' ),
		'std'        => scribbler_get_settings( 'primary_color_scheme' ),
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'       => 'mts_pagenavigation_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Pagination Margin', 'scribbler' ),
		'sub_desc' => esc_html__( 'Update pagination margin from here.', 'scribbler' ),
		'std'      => array(
			'top'    => '0',
			'right'  => '3px',
			'bottom' => '0',
			'left'   => '3px',
		),
	),
	array(
		'id'         => 'mts_pagenavigation_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Pagination Padding', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Update pagination padding from here.', 'scribbler' ),
		'std'        => array(
			'top'    => '8px',
			'right'  => '10px',
			'bottom' => '8px',
			'left'   => '10px',
		),
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Load More Padding', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Update padding for load more button from here.', 'scribbler' ),
		'std'        => array(
			'top'    => '15px',
			'right'  => '35px',
			'bottom' => '15px',
			'left'   => '35px',
		),
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'         => 'mts_pagenavigation_border_radius',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Pagination border radius', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Update pagination border radius in px.', 'scribbler' ),
		'std'        => '35',
		'args'       => array( 'type' => 'number' ),
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_border_radius',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Load More border radius', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Update Load More border radius in px.', 'scribbler' ),
		'std'        => '3',
		'args'       => array( 'type' => 'number' ),
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'         => 'pagenavigation_border',
		'type'       => 'border',
		'title'      => esc_html__( 'Border', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Select border', 'scribbler' ),
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'load_more_border',
		'type'       => 'border',
		'title'      => esc_html__( 'Border', 'scribbler' ),
		'sub_desc'   => esc_html__( 'Select border', 'scribbler' ),
		'dependency' => $loadmore_button_dependency,
	),
	array(
		'id'         => 'pagination_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Pagination Font', 'scribbler' ),
		'color'      => false,
		'std'        => array(
			'preview-text'   => 'Pagination Font',
			'preview-color'  => 'light',
			'font-family'    => 'Asap',
			'font-weight'    => '700',
			'font-size'      => '22px',
			'line-height'    => '1',
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.pagination, .pagination a',
		),
		'dependency' => $default_pagination_dependency,
	),
	array(
		'id'         => 'loadmore_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Load More Font', 'scribbler' ),
		'color'      => false,
		'std'        => array(
			'preview-text'  => 'Load More Font',
			'preview-color' => 'light',
			'font-family'   => 'Asap',
			'font-weight'   => '700',
			'font-size'     => '14px',
			'css-selectors' => '#load-posts a',
		),
		'dependency' => $loadmore_button_dependency,
	),

);
