<?php
/**
 * HomePage Posts
 *
 * @package Scribbler
 */

$features = scribbler_get_settings( 'featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = array(
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'scribbler' ) ), $title ),
	);

	// Dependency check that back to top option is enable.
	$post_title_dependency = array(
		'relation' => 'and',
		array(
			'field'      => 'featured_category_title_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$readmore = array(
		'relation' => 'and',
		array(
			'field'      => 'readmore_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$sections[ 'blog-' . $unique_id ] = array(

		/**
		 * Layout Default Settings
		 *
		 * @package Scribbler
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'scribbler' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'scribbler' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'scribbler' ),
			'std'      => '0',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'scribbler' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'scribbler' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'scribbler' ),
				'center' => esc_html__( 'Center', 'scribbler' ),
				'right'  => esc_html__( 'Right', 'scribbler' ),
			),
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'scribbler' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'scribbler' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'scribbler' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'scribbler' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '30px',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'scribbler' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'scribbler' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'scribbler' ),
			'sub_desc'   => esc_html__( 'Select border', 'scribbler' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'scribbler' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Asap',
				'font-weight'    => '700',
				'font-size'      => '16px',
				'color'          => '#2b2b2b',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'scribbler' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'digital' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Read More.', 'digital' ),
			'std'      => '1',
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info_' . $unique_id,
			'type'     => 'multi_checkbox',
			'title'    => esc_html__( 'Post Meta Info', 'scribbler' ),
			'sub_desc' => esc_html__( 'Show or hide post meta info.', 'scribbler' ),
			'options'  => array(
				'category'  => esc_html__( 'Category', 'scribbler' ),
				'date'      => esc_html__( 'Date', 'scribbler' ),
				'authorpic' => esc_html__( 'Author Pic', 'scribbler' ),
				'author'    => esc_html__( 'Author Name', 'scribbler' ),
				'comment'   => esc_html__( 'Comments', 'scribbler' ),
			),
			'std'      => array(
				'category',
				'date',
				'authorpic',
				'author',
				'comment',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_home_category_type_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Categories', 'scribbler' ),
			'options'  => array(
				'0' => esc_html__( 'First Category', 'scribbler' ),
				'1' => esc_html__( 'ALL Categories', 'scribbler' ),
			),
			'sub_desc' => esc_html__( 'Show only first category or all the categories of post from here.', 'scribbler' ),
			'std'      => '0',
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'scribbler' ),
			'sub_desc' => esc_html__( 'Select border.', 'scribbler' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'meta_info_upper_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Date Typography', 'scribbler' ),
			'std'   => array(
				'preview-text'   => 'Date Font',
				'preview-color'  => 'light',
				'font-family'    => 'Asap',
				'font-weight'    => '700',
				'font-size'      => '14px',
				'color'          => '#6f727d',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .post-info-upper, .layout-' . $unique_id . ' .post-info-upper a',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_categories_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Categories Typography', 'scribbler' ),
			'std'   => array(
				'preview-text'   => 'Post Categories Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Asap',
				'font-weight'    => '700',
				'font-size'      => '14px',
				'color'          => '#ffffff',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .post-info-upper .thecategory a',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'    => 'meta_info_bottom_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Author, Comments Typography', 'scribbler' ),
			'std'   => array(
				'preview-text'   => 'Post Author, Comments Font',
				'preview-color'  => 'light',
				'font-family'    => 'Asap',
				'font-weight'    => '400',
				'font-size'      => '16px',
				'color'          => '#3f4351',
				'additional-css' => 'text-transform: capitalize;',
				'css-selectors'  => '.layout-' . $unique_id . ' .post-info-bottom, .layout-' . $unique_id . ' .post-info-bottom a',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_categories_bg_' . $unique_id,
			'type'  => 'color',
			'title' => esc_html__( 'Categories Background', 'scribbler' ),
			'std'   => scribbler_get_settings( 'primary_color_scheme' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_categories_hover_bg_' . $unique_id,
			'type'  => 'color',
			'title' => esc_html__( 'Categories Hover Background', 'scribbler' ),
			'std'   => '#b34a4e',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Read More Font', 'digital' ),
			'std'        => array(
				'preview-text'  => 'Read More Font',
				'preview-color' => 'light',
				'font-family'   => 'Red Hat Display',
				'font-weight'   => '700',
				'font-size'     => '16px',
				'line-height'   => '20px',
				'color'         => '#9fa1a8',
				'css-selectors' => '.layout-' . $unique_id . ' .readMore a',
			),
			'dependency' => $readmore,
		) : null,
		// Post Container.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'scribbler' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'scribbler' ),
			'sub_desc' => esc_html__( 'Select border', 'scribbler' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'scribbler' ),
			'sub_desc' => esc_html__( 'Post margin.', 'scribbler' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'scribbler' ),
			'sub_desc' => esc_html__( 'Post padding.', 'scribbler' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'scribbler' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Asap',
				'font-weight'   => '700',
				'font-size'     => '38px',
				'line-height'   => '48px',
				'color'         => '#3f4351',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'scribbler' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Asap',
				'font-weight'   => '400',
				'font-size'     => '16px',
				'line-height'   => '30px',
				'color'         => '#9fa1a8',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout 1 with 2 sidebars Settings
		 *
		 * @package Scribbler
		 */
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_left_sidebar_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Left Sidebar', 'scribbler' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide left sidebar.', 'scribbler' ),
			'std'      => '1',
		) : null,

		// Meta info.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'scribbler' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'digital' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Read More.', 'digital' ),
			'std'      => '1',
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'scribbler' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'scribbler' ) ), $title ),
			'options'  => array(
				'enabled'  => array(),
				'disabled' => array(
					'author'   => array(
						'label'     => esc_html__( 'Author Name', 'scribbler' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'scribbler' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'scribbler' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'scribbler' ),
							),
						),
					),
					'comment'  => array(
						'label'     => esc_html__( 'Comment Count', 'scribbler' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'scribbler' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'scribbler' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'scribbler' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(),
				'disabled' => array(
					'date'     => array(
						'label'     => esc_html__( 'Date', 'scribbler' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'scribbler' ),
							),
						),
					),
					'comment'  => array(
						'label'     => esc_html__( 'Comment Count', 'scribbler' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'scribbler' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'scribbler' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'scribbler' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'scribbler' ),
			'sub_desc' => esc_html__( 'Select border.', 'scribbler' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'scribbler' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Asap',
				'font-weight'    => '700',
				'font-size'      => '14px',
				'line-height'    => '1.8',
				'color'          => '#6f727d',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .post-info, .layout-' . $unique_id . ' .post-info a',
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_categories_color_' . $unique_id,
			'type'  => 'color',
			'title' => esc_html__( 'Post Categories Color', 'scribbler' ),
			'std'   => scribbler_get_settings( 'primary_color_scheme' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'readmore_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Read More Font', 'digital' ),
			'std'        => array(
				'preview-text'  => 'Read More Font',
				'preview-color' => 'light',
				'font-family'   => 'Red Hat Display',
				'font-weight'   => '700',
				'font-size'     => '15px',
				'line-height'   => '20px',
				'color'         => '#9fa1a8',
				'css-selectors' => '.layout-' . $unique_id . ' .readMore a',
			),
			'dependency' => $readmore,
		) : null,
		// Post Container.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'scribbler' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'scribbler' ),
			'sub_desc' => esc_html__( 'Select border', 'scribbler' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'scribbler' ),
			'sub_desc' => esc_html__( 'Post margin.', 'scribbler' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '68px',
				'bottom' => '0',
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'scribbler' ),
			'sub_desc' => esc_html__( 'Post padding.', 'scribbler' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'scribbler' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Asap',
				'font-weight'   => '700',
				'font-size'     => '24px',
				'line-height'   => '1.2',
				'color'         => '#3f4351',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'scribbler' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Asap',
				'font-weight'   => '400',
				'font-size'     => '15px',
				'line-height'   => '28px',
				'color'         => '#6f727d',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout HTML Settings
		 *
		 * @package Scribbler
		 */
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_layout_html_' . $unique_id,
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'HTML Post', 'scribbler' ),
			'sub_desc' => esc_html__( 'Paste your HTML, Text or other code here.', 'scribbler' ),
			'std'      => '<img src="' . get_template_directory_uri() . '/images/banner-970.jpg">',
		) : null,
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'scribbler' ),
			'sub_desc' => esc_html__( 'Post margin.', 'scribbler' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '45px',
				'bottom' => '0',
			),
		) : null,
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'scribbler' ),
			'sub_desc' => esc_html__( 'Post padding.', 'scribbler' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

	);
endforeach;
